@@ -1,5 +1,12 @@
 from .buttons import CallbackButton, UrlButton
-from .contexts import QueryContext, TextContext, UpdateContext
+from .contexts import (
+    QueryCallback,
+    QueryContext,
+    TextCallback,
+    TextContext,
+    UpdateCallback,
+    UpdateContext,
+)
 from .handlers import (
     CommandHandler,
     CompositeHandler,
@@ -29,4 +36,7 @@ __all__ = [
     "UpdateContext",
     "QueryContext",
     "TextContext",
+    "UpdateCallback",
+    "QueryCallback",
+    "TextCallback",
 ]
