@@ -9,7 +9,7 @@ class Texts:
 
     def get_words(self, key: int) -> list[str]:
         text = self[key]
-        return [i.lower() for i in text.split()]
+        return text.lower().split()
 
     def __getitem__(self, item: int) -> str:
         key = str(item)
